About
=====

This is a ctypes based python wrapper for snap7. Snap7 is an open source,
32/64 bit, multi-platform Ethernet communication suite for interfacing natively
with Siemens S7 PLCs.

python-snap7 is tested with Python 2.7 and 3.5+, on Windows, Linux and OS X.

.. image:: https://travis-ci.org/gijzelaerr/python-snap7.png?branch=master 
  :target: https://travis-ci.org/gijzelaerr/python-snap7

.. image:: http://codecov.io/github/gijzelaerr/python-snap7/coverage.svg?branch=master
  :target: http://codecov.io/github/gijzelaerr/python-snap7?branch=master

The full documentation is available on `Read The Docs <http://python-snap7.readthedocs.org/en/latest/>`_.

see `python-snap7 in action <http://youtu.be/G-Gj_r2BQBk/>`_.

Installation
============

Please read the
`online installation documentation <http://python-snap7.readthedocs.org/en/latest/installation.html>`_.


credits
=======

- Gijs Molenaar (gijs at pythonic dot nl)
- Stephan Preeker (stephan at preeker dot net)

Both authors are available for contracting to improve python-snap7. Please contact us at the email address above for inquiries.


Special thanks to
=================

- Davide Nardella for creating snap7
- Thomas Hergenhahn for his libnodave.
- Thomas W for his S7comm wireshark plugin
